(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2007-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux <Quentin.Carbonneaux@inria.fr>                 *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: options.ml,v 1.10 2014/01/21 09:21:18 fclement Exp $ *)

let chars_per_col = 50
and min_number_of_workers = 1
and min_number_of_iterations = 100
and min_number_of_decimals = 1
;;

let default_number_of_workers = 2
and default_number_of_iterations = min_number_of_iterations
and default_number_of_decimals = 98
;;

let my_make_aref with_assignment name default n =
  Uaref.make_aref_gen
    (Uaref.with_int_bounds (Some n) None
      (Uaref.with_name name
        (with_assignment
          (Uaref.aref_spec default))))
;;

let make_single_aref_with_min name =
  my_make_aref Uaref.with_single_assignment name
;;

let { Uaref.get = get_number_of_workers; set = set_number_of_workers; } =
  make_single_aref_with_min
    "number_of_workers"
    default_number_of_workers
    min_number_of_workers

and { Uaref.get = get_number_of_iterations; set = set_number_of_iterations; } =
  make_single_aref_with_min
    "number_of_iterations"
    default_number_of_iterations
    min_number_of_iterations

and { Uaref.get = get_number_of_decimals; set = set_number_of_decimals; } =
  make_single_aref_with_min
    "number_of_decimals"
    default_number_of_decimals
    min_number_of_decimals
;;

let add_options () =
  Ucommand_option.user_add_all
    (List.map
       (fun (rco, sk) ->
         Ucommand_option.with_short_key sk
           (Ucommand_option.of_regular rco))
       [
        ({
          Ucommand_option.key = "--number-of-workers";
          spec = Arg.Int set_number_of_workers;
          doc =
            Printf.sprintf
              "<int>  Set the number of effective workers. \
              Default is %d."
              (get_number_of_workers ());
         },
         "-nw");
        
        ({
          Ucommand_option.key = "--number-of-iterations";
          spec = Arg.Int set_number_of_iterations;
          doc =
            Printf.sprintf
              "<int>  Set the number of iterations of the BBP formula.\n\
              \tDefault is %d. \
              Cannot be lower than %d."
              (get_number_of_iterations ()) min_number_of_iterations;
         },
         "-ni");
        
        ({
          Ucommand_option.key = "--number-of-decimals";
          spec = Arg.Int set_number_of_decimals;
          doc =
            Printf.sprintf
              "<int>  Set the number of decimals printed. \
              Default is %d."
              (get_number_of_decimals ());
         },
         "-nd");
       ]);
;;

Ucommand_option.set_usage_msg
  (Printf.sprintf
     "\n%s -- Sklml demo code\n"
     Sys.argv.(0))
;;
