(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2007-2012 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux <Quentin.Carbonneaux@inria.fr>                 *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: pool.ml,v 1.8 2012/02/17 14:38:55 fclement Exp $ *)

type 'a pool = {
  cache : (int, 'a) Hashtbl.t;
  mk_filename : int -> string;
  mk_tmp_filename : unit -> string;
}
(** A pool is a persistant data structure which maps an integer
  to a value of type ['a]. *)

type 'a t = 'a pool

let get_contents fn =
  let ic = open_in fn in
  let x = input_value ic in
  close_in ic; x

let set_contents fn tmp_file x =
  (* if Unix.fork () = 0 then *)
    let oc = open_out tmp_file in
    output_value oc x; close_out oc;
    Sys.rename tmp_file fn
    (* exit 0 *)
  (* else () *)

let find pool i =
  try Hashtbl.find pool.cache i with Not_found ->
    let fn = pool.mk_filename i in
    match Sys.file_exists fn with
    | true ->
      let x = get_contents fn in
      Hashtbl.add pool.cache i x; x
    | false -> raise Not_found

let add pool i x =
  Hashtbl.remove pool.cache i;
  set_contents (pool.mk_filename i) (pool.mk_tmp_filename ()) x

let create dir tdir n =
  if not (Sys.is_directory dir) then invalid_arg "Pool.create" else
  { cache = Hashtbl.create n;
    mk_filename = (fun i -> Filename.concat dir (string_of_int i));
    mk_tmp_filename =
      (fun () -> Filename.temp_file ~temp_dir:tdir "caml" "pool"); }

let clear_cache { cache = c; _ } =
  Hashtbl.clear c
