#######################################################################
#                                                                     #
#                                 Pph                                 #
#                                                                     #
#                    The Portable Project Handler                     #
#                                                                     #
#               EPI Pomdapi, INRIA Paris - Rocquencourt               #
#                                                                     #
#  Copyright 2005-2013 INRIA.                                         #
#  Institut National de Recherche en Informatique et en Automatique.  #
#  All rights reserved. This file is distributed only by permission.  #
#                                                                     #
#  Francois Clement <Francois.Clement@inria.fr>                       #
#  Pierre Weis <Pierre.Weis@inria.fr>                                 #
#                                                                     #
#######################################################################

# $Id: unconfigure.profile,v 1.19 2013/05/15 19:48:01 fclement Exp $

# User unconfiguration profile.
#
# This profile is sourced by the user unconfiguration script
#``unconfigure_user'' in the root directory of the Pph project.
# It assumes that the variable PROJECT_ROOT_DIR is set to an absolute path.

# Load user Pph system directory names.
. "${PROJECT_ROOT_DIR:?}"/pph/user/scripts/Pph_dirs.profile

# Load error codes.
. "${PPH_USER_SCRIPTS_DIR:?}"/error_codes.profile

# Load basic commands.
. "${PPH_USER_SCRIPTS_DIR:?}"/basic_commands.profile

# Load script functions.
. "${PPH_USER_SCRIPTS_DIR:?}"/script_functions.profile

# Load  intrinsic defaults.
. "${PPH_USER_SCRIPTS_DIR:?}"/intrinsic_defaults.profile
DEVEL_MODE=false

# Load the ID card of the Pph project.
. "${PROJECT_CONFIG_DIR:?}"/Project.profile

# Load unconfiguration usage.
. "${PPH_USER_SCRIPTS_DIR:?}"/unconfigure_usage.profile

# Parse unconfiguration options.
. "${PPH_USER_SCRIPTS_DIR:?}"/unconfigure_parsing.profile

report_message "Profile launched"

# Load user configuration settings.
. "${USER_CONFIGURE_SETTINGS_PROFILE:?}"

# Remove the configure options.
report_message "Removing the configure options"
$RM "${USER_CONFIGURE_CMD_LINE_ARGS}"

# Uninstall the Pph user pervasive tools.
uninstall_pph_pervasive_tools "$PPH_USER_PERVASIVE_TOOLS"
IER=$?
if test $IER -ne 0; then exit $IER; fi
remove_pph_private_install_dir

# Remove user's preambles and stop on errors.
report_message "Launching user's unconfiguration makefile"
$RM ${USER_MAKE_CONFIGURE_LOG:?}
make_quiet unconfigure
IER=$?
if test $IER -ne 0; then exit $IER; fi

# Remove the Pph user preamble in the root directory of the Pph project.
report_message "Removing user preamble in the root directory"
$RM "${USER_PREAMBLE_FILE:?}"

# Remove the ``.Project_path'' file in the source directory of the Pph user
# pervasive tools. There are none for the moment...
remove_path_file_in_pph_pervasive_tools "$PPH_USER_PERVASIVE_TOOLS"

# Remove the ``.Project_path'' file in the root directory of the Pph project.
report_message "Removing project path in the root directory"
$RM "${PROJECT_PATH_FILE:?}"

# Uninstall the Pph core pervasive tools.
uninstall_pph_pervasive_tools "${PPH_CORE_PERVASIVE_TOOLS:?}"
IER=$?
if test $IER -ne 0; then exit $IER; fi
remove_empty_dir_and_parents "${PPH_BIN_DIR:?}"

# Remove private tools.
report_message "Removing private tools"
remove_private_tools "${PROJECT_TARBALLS_DIR:?}"

# Remove configuration files.
report_message "Removing configuration files"
$RM "${USER_CONFIGURE_SETTINGS_PROFILE:?}"
$RM "${USER_CONFIGURE_SETTINGS_PPH:?}"
$RM "${USER_CONFIGURE_SETTINGS_ENV:?}"

# Remove temporary configuration directories.
report_message "Removing temporary configuration directories"
$RM "${PROJECT_SUMMARIES_DIR:?}"
$RM "${PROJECT_CHECKPOINTS_DIR:?}"
remove_empty_dir_and_parents "${PROJECT_RUNTIME_DIR:?}"

report_message "Profile done"
