(***********************************************************************)
(*                                                                     *)
(*                                Sklml                                *)
(*                                                                     *)
(*                 The OCaml parallel skeleton system                  *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2007-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Quentin Carbonneaux <Quentin.Carbonneaux@inria.fr>                 *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: skl_comm.mli,v 1.15 2014/01/21 09:21:16 fclement Exp $ *)

(* Glue library between sklml programs and the Sklml parallel launcher daemon *)

(* Requests' type *)

type atom_id = int;;

type color = int;;

type request =
   | Atom_req of Obj.t * atom_id * color
   | Loop_req of Iotree.ioatree * Iotree.ioatree
   | Pipe_req of Iotree.ioatree * Iotree.ioatree
;;

(* Replies' type *)

type port = int;;

type reply =
   | Success of Unix.sockaddr
   | Failure
;;

(* Functions *)

type iochans = IO.ic * IO.oc;;

val request_daemon : iochans -> request -> reply option;;
val extract_request : IO.ic -> request;;
val send_reply : IO.oc -> reply -> unit;;

val open_skl_fifo : bool -> int -> iochans;;
val clean_skl_fifo : int -> unit;;
